Crate fips_endpoint

Crate fips_endpoint 

App-facing FIPS endpoint API.

Structs

Config
Root configuration structure.
EthernetConfig
Ethernet transport instance configuration.
FipsAddress
128-bit FIPS address with IPv6-compatible format.
FipsEndpoint
A running embedded FIPS endpoint.
FipsEndpointBuilder
Builder for an embedded FIPS endpoint.
FipsEndpointDirectPacketBatch
Established endpoint packet runs delivered without the endpoint-event queue.
FipsEndpointDirectPacketRun
Consecutive direct endpoint packets from one authenticated FIPS source.
FipsEndpointMessage
Source-attributed endpoint data delivered to an embedded application.
FipsEndpointPeer
Authenticated FIPS peer state visible to an embedded application.
FipsEndpointRelayStatus
Live Nostr relay state visible to an embedded application.
Identity
A FIPS node identity consisting of a keypair and derived identifiers.
NodeAddr
16-byte node identifier derived from truncated SHA-256(pubkey).
NostrDiscoveryConfig
Nostr-mediated overlay endpoint discovery (node.discovery.nostr.*).
PeerAddress
A transport-specific address for reaching a peer.
PeerConfig
Configuration for a known peer.
PeerIdentity
A known peer’s identity (public key only, no signing capability).
TransportsConfig
Transports configuration section.
UdpConfig
UDP transport instance configuration.
UpdatePeersOutcome
Reports what changed in response to FipsEndpoint::update_peers.

Enums

ConnectPolicy
Connection policy for a peer.
FipsEndpointDirectDeliveryError
Error returned by an installed direct endpoint sink.
FipsEndpointError
Errors returned by the endpoint API.
IdentityError
Errors that can occur in identity operations.
NostrDiscoveryPolicy
Nostr advert discovery policy.
RoutingMode
Daemon routing mode.
TransportInstances
Transport instances - either a single config or named instances.

Traits

FipsEndpointDirectSink
Application-provided direct dataplane endpoint delivery sink.

Functions

decode_npub
Decode an npub string to an x-only public key.
decode_nsec
Decode an nsec string to a secret key.
decode_secret
Decode a secret key from either nsec (bech32) or hex format.
encode_npub
Encode an x-only public key as a bech32 npub string (NIP-19).
encode_nsec
Encode a secret key as a bech32 nsec string (NIP-19).

Type Aliases

FipsEndpointData
Endpoint data bytes delivered by FIPS.