App-facing FIPS endpoint API.
Structs
- Config
- Root configuration structure.
- Fips
Address - 128-bit FIPS address with IPv6-compatible format.
- Fips
Endpoint - A running embedded FIPS endpoint.
- Fips
Endpoint Builder - Builder for an embedded FIPS endpoint.
- Fips
Endpoint Message - Source-attributed endpoint data delivered to an embedded application.
- Fips
Endpoint Peer - Authenticated FIPS peer state visible to an embedded application.
- Fips
Endpoint Relay Status - Live Nostr relay state visible to an embedded application.
- Identity
- A FIPS node identity consisting of a keypair and derived identifiers.
- Node
Addr - 16-byte node identifier derived from truncated SHA-256(pubkey).
- Nostr
Discovery Config - Nostr-mediated overlay endpoint discovery (
node.discovery.nostr.*). - Peer
Address - A transport-specific address for reaching a peer.
- Peer
Config - Configuration for a known peer.
- Peer
Identity - A known peer’s identity (public key only, no signing capability).
- Transports
Config - Transports configuration section.
- UdpConfig
- UDP transport instance configuration.
- Update
Peers Outcome - Reports what changed in response to
FipsEndpoint::update_peers.
Enums
- Connect
Policy - Connection policy for a peer.
- Fips
Endpoint Error - Errors returned by the endpoint API.
- Identity
Error - Errors that can occur in identity operations.
- Nostr
Discovery Policy - Nostr advert discovery policy.
- Routing
Mode - Daemon routing mode.
- Transport
Instances - Transport instances - either a single config or named instances.
Functions
- decode_
npub - Decode an npub string to an x-only public key.
- decode_
nsec - Decode an nsec string to a secret key.
- decode_
secret - Decode a secret key from either nsec (bech32) or hex format.
- encode_
npub - Encode an x-only public key as a bech32 npub string (NIP-19).
- encode_
nsec - Encode a secret key as a bech32 nsec string (NIP-19).