pub trait FipsEndpointDirectSink:
Send
+ Sync
+ 'static {
// Required method
fn deliver_endpoint_packet_batch(
&self,
batch: FipsEndpointDirectPacketBatch,
) -> Result<(), FipsEndpointDirectDeliveryError>;
}Expand description
Application-provided direct dataplane endpoint delivery sink.
This sink is called synchronously from the dataplane output path with owned packet buffers. It should return quickly and avoid blocking unrelated dataplane progress.
Required Methods
Sourcefn deliver_endpoint_packet_batch(
&self,
batch: FipsEndpointDirectPacketBatch,
) -> Result<(), FipsEndpointDirectDeliveryError>
fn deliver_endpoint_packet_batch( &self, batch: FipsEndpointDirectPacketBatch, ) -> Result<(), FipsEndpointDirectDeliveryError>
Deliver established endpoint data as authenticated packet runs.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".