pub type FipsEndpointData = PacketBuffer;Expand description
Endpoint data bytes delivered by FIPS.
This is the same pooled packet owner used by the transport/dataplane, so embedders can forward endpoint data without forcing another hot-path copy.
Aliased Type
pub struct FipsEndpointData { /* private fields */ }